@@ -32,29 +32,35 @@ logger = createLogger(__name__)
 
 NEWSKETTER_BLACKCONTACT_SEARCH_URL = "https://newsletter.nuwainfo.com/newsletters/newsletter/blackcontact/search/"
 
+def filterBlacklist(emailMessages):
+    # filter black contact 
+    emailMessagesAfterFilter = []
+    for message in emailMessages:
+        try:
+            payload = {
+                "emails": message.to,
+            }
+            response = json.loads(
+                requests.post(NEWSKETTER_BLACKCONTACT_SEARCH_URL, data=payload, 
+                timeout=getattr(settings, "IUNO_EMAIL_BACKEND_SEARCH_BLACKCONTACT_TIMEOUT", 1)
+            ).text)
+            emails = [result['email'] for result in response.get("results", [])]
+            if emails:
+                message.to = [email for email in message.to if not email in emails]
+            
+            if message.to:
+                emailMessagesAfterFilter.append(message) 
+        except Exception as e:
+            logger.error(str(e))
+            emailMessagesAfterFilter.append(message)
+            
+    return emailMessagesAfterFilter
+    
+
 class ConfiguredEmailBackend(_ConfiguredEmailBackend):
     def send_messages(self, emailMessages):
         # filter black contact 
-        emailMessagesAfterFilter = []
-        for message in emailMessages:
-            try:
-                payload = {
-                    "emails": message.to,
-                }
-                response = json.loads(
-                    requests.post(NEWSKETTER_BLACKCONTACT_SEARCH_URL, data=payload, 
-                    timeout=getattr(settings, "IUNO_EMAIL_BACKEND_SEARCH_BLACKCONTACT_TIMEOUT", 1)
-                ).text)
-                emails = [result['email'] for result in response.get("results", [])]
-                if emails:
-                    message.to = [email for email in message.to if not email in emails]
-                
-                if message.to:
-                    emailMessagesAfterFilter.append(message) 
-            except Exception as e:
-                logger.error(str(e))
-                emailMessagesAfterFilter.append(message)
-        emailMessages = emailMessagesAfterFilter
+        emailMessages = filterBlacklist(emailMessages)
         
         fromEmailList = []
         try:
